@@ -4,7 +4,7 @@ import typing as tp
 from aiohttp import ClientSession
 
 
-BASE_URL = 'https://api.zoom.us/v2/'
+BASE_URL = 'https://api.zoom.us/v2'
 
 class Client:
     """
@@ -17,12 +17,14 @@ class Client:
     async def get(self, method: str, *args: tp.Any, **kwargs: tp.Any) -> tp.Any:
         async with ClientSession() as session:
             async with session.get(f'{self.base_url}/{method}', *args, **kwargs) as response:
+                print(response.text)
                 data = await response.json()
                 return data
 
     async def post(self, method: str, *args: tp.Any, **kwargs: tp.Any) -> tp.Any:
         async with ClientSession() as session:
             async with session.post(f"{self.base_url}/{method}", *args, **kwargs) as response:
+                print(response.text)
                 data = await response.json()
                 return data
 
